.. Copyright 2023 Ross J. Duff MSc 
   The copyright holder licenses this file
   to you under the Apache License, Version 2.0 (the
   "License"); you may not use this file except in compliance
   with the License.  You may obtain a copy of the License at

      http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing,
   software distributed under the License is distributed on an
   "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
   KIND, either express or implied.  See the License for the
   specific language governing permissions and limitations
   under the License.

========
OZI lint
========

Codebase linting and formatting.

Default Toolchain
-----------------

* Bandit_:
  A tool designed to find common security issues in Python code.
* Black_:
  The uncompromising code formatter.
* Flake8_:
  A wrapper around PyFlakes_, pycodestyle_ and Ned Batchelder's McCabe_ script.
* isort_:
  Sort imports alphabetically, and automatically separated into sections and by type. 
* Pylint_:
  A static code analyser for Python
* Pyright_:
  A full-featured, standards-based static type checker for Python.
* restructuredtext-lint_:
  Python Packaging Authority flavoured reST linting.

.. _Bandit: https://pypi.org/project/bandit/
.. _Black: https://pypi.org/project/black/
.. _Flake8: https://pypi.org/project/flake8
.. _Pyflakes: https://pypi.org/project/pyflakes/
.. _pycodestyle: https://pypi.org/project/pycodestyle/
.. _McCabe: https://pypi.org/project/mccabe/
.. _isort: https://pypi.org/project/isort/
.. _Pylint: https://pypi.org/project/pylint/
.. _Pyright: https://pypi.org/project/pyright/
.. _restructuredtext-lint: https://pypi.org/project/restructuredtext-lint/